from lakefs_client.paths.repositories_repository_branches_branch_commits.get import ApiForget
from lakefs_client.paths.repositories_repository_branches_branch_commits.post import ApiForpost


class RepositoriesRepositoryBranchesBranchCommits(
    ApiForget,
    ApiForpost,
):
    pass
