from lakefs_client.paths.auth_users_user_id_credentials.get import ApiForget
from lakefs_client.paths.auth_users_user_id_credentials.post import ApiForpost


class AuthUsersUserIdCredentials(
    ApiForget,
    ApiForpost,
):
    pass
