# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from lakefs_client import schemas  # noqa: F401


class FindMergeBaseResult(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "destination_commit_id",
            "base_commit_id",
            "source_commit_id",
        }
        
        class properties:
            source_commit_id = schemas.StrSchema
            destination_commit_id = schemas.StrSchema
            base_commit_id = schemas.StrSchema
            __annotations__ = {
                "source_commit_id": source_commit_id,
                "destination_commit_id": destination_commit_id,
                "base_commit_id": base_commit_id,
            }
    
    destination_commit_id: MetaOapg.properties.destination_commit_id
    base_commit_id: MetaOapg.properties.base_commit_id
    source_commit_id: MetaOapg.properties.source_commit_id
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["source_commit_id"]) -> MetaOapg.properties.source_commit_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["destination_commit_id"]) -> MetaOapg.properties.destination_commit_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["base_commit_id"]) -> MetaOapg.properties.base_commit_id: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["source_commit_id", "destination_commit_id", "base_commit_id", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["source_commit_id"]) -> MetaOapg.properties.source_commit_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["destination_commit_id"]) -> MetaOapg.properties.destination_commit_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["base_commit_id"]) -> MetaOapg.properties.base_commit_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["source_commit_id", "destination_commit_id", "base_commit_id", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        destination_commit_id: typing.Union[MetaOapg.properties.destination_commit_id, str, ],
        base_commit_id: typing.Union[MetaOapg.properties.base_commit_id, str, ],
        source_commit_id: typing.Union[MetaOapg.properties.source_commit_id, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'FindMergeBaseResult':
        return super().__new__(
            cls,
            *_args,
            destination_commit_id=destination_commit_id,
            base_commit_id=base_commit_id,
            source_commit_id=source_commit_id,
            _configuration=_configuration,
            **kwargs,
        )
