from lakefs_client.paths.auth_groups_group_id_members_user_id.put import ApiForput
from lakefs_client.paths.auth_groups_group_id_members_user_id.delete import ApiFordelete


class AuthGroupsGroupIdMembersUserId(
    ApiForput,
    ApiFordelete,
):
    pass
