# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_branches_branch_commits.post import Commit
from lakefs_client.paths.repositories_repository_commits_commit_id.get import GetCommit
from lakefs_client.paths.repositories_repository_branches_branch_commits.get import LogBranchCommits


class CommitsApi(
    Commit,
    GetCommit,
    LogBranchCommits,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
