# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_actions_runs_run_id.get import GetRun
from lakefs_client.paths.repositories_repository_actions_runs_run_id_hooks_hook_run_id_output.get import GetRunHookOutput
from lakefs_client.paths.repositories_repository_actions_runs.get import ListRepositoryRuns
from lakefs_client.paths.repositories_repository_actions_runs_run_id_hooks.get import ListRunHooks


class ActionsApi(
    GetRun,
    GetRunHookOutput,
    ListRepositoryRuns,
    ListRunHooks,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
