from lakefs_client.paths.repositories_repository_actions_runs_run_id_hooks_hook_run_id_output.get import ApiForget


class RepositoriesRepositoryActionsRunsRunIdHooksHookRunIdOutput(
    ApiForget,
):
    pass
