from lakefs_client.paths.repositories_repository_branches_branch.get import ApiForget
from lakefs_client.paths.repositories_repository_branches_branch.put import ApiForput
from lakefs_client.paths.repositories_repository_branches_branch.delete import ApiFordelete


class RepositoriesRepositoryBranchesBranch(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass
