from lakefs_client.paths.repositories_repository_refs_source_ref_merge_destination_branch.get import ApiForget
from lakefs_client.paths.repositories_repository_refs_source_ref_merge_destination_branch.post import ApiForpost


class RepositoriesRepositoryRefsSourceRefMergeDestinationBranch(
    ApiForget,
    ApiForpost,
):
    pass
