# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

from lakefs_client.paths.repositories_repository_branches_branch_objects_copy.post import CopyObject
from lakefs_client.paths.repositories_repository_branches_branch_objects.delete import DeleteObject
from lakefs_client.paths.repositories_repository_branches_branch_objects_delete.post import DeleteObjects
from lakefs_client.paths.repositories_repository_refs_ref_objects.get import GetObject
from lakefs_client.paths.repositories_repository_refs_ref_objects_underlying_properties.get import GetUnderlyingProperties
from lakefs_client.paths.repositories_repository_refs_ref_objects.head import HeadObject
from lakefs_client.paths.repositories_repository_refs_ref_objects_ls.get import ListObjects
from lakefs_client.paths.repositories_repository_branches_branch_objects.put import StageObject
from lakefs_client.paths.repositories_repository_refs_ref_objects_stat.get import StatObject
from lakefs_client.paths.repositories_repository_branches_branch_objects.post import UploadObject


class ObjectsApi(
    CopyObject,
    DeleteObject,
    DeleteObjects,
    GetObject,
    GetUnderlyingProperties,
    HeadObject,
    ListObjects,
    StageObject,
    StatObject,
    UploadObject,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
