from lakefs_client.paths.repositories_repository_tags.get import ApiForget
from lakefs_client.paths.repositories_repository_tags.post import ApiForpost


class RepositoriesRepositoryTags(
    ApiForget,
    ApiForpost,
):
    pass
