# coding: utf-8

"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""

import unittest

import lakefs_client
from lakefs_client.model.object_stats_list import ObjectStatsList
from lakefs_client import configuration


class TestObjectStatsList(unittest.TestCase):
    """ObjectStatsList unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
